"use client";

import { useRef, useState } from "react";
import { Swiper, SwiperSlide } from "swiper/react";
import { Grid } from "swiper/modules";

import "swiper/css/grid";
import { IconButton } from "@mui/material";
import { ChevronLeft, ChevronRight } from "@mui/icons-material";
import ExamCard from "../cards/ExamCard";

const ExamsListSwiperDemo = ({ exams, handleSetExam }) => {
  console.log(exams)
  //* swiper controller
  const swiperRef = useRef(null);
  const [isBeginning, setIsBeginning] = useState(true);
  const [isEnd, setIsEnd] = useState(false);

  const handleNext = () => {
    if (swiperRef.current && !isEnd) {
      swiperRef.current.swiper.slideNext();
    }
  };

  const handlePrev = () => {
    if (swiperRef.current && !isBeginning) {
      swiperRef.current.swiper.slidePrev();
    }
  };

  const handleSlideChange = (swiper) => {
    setIsBeginning(swiper.isBeginning);
    setIsEnd(swiper.isEnd);
  };

  return (
    <div className="w-full  flex flex-col gap-4 ">
      <div className="item-grid h-[359px]  ">
        <Swiper
          ref={swiperRef}
          onSlideChange={handleSlideChange}
          className="comment-swiper"
          direction="horizontal"
          spaceBetween={16}
          style={{
            width: "100%",
            height: "100%",
            maxWidth: "100%",
            paddingBottom: "6px",
            paddingTop: "6px",
            paddingRight: "6px",
          }}
          slidesPerView={"auto"}
          modules={[Grid]}
          grid={{
            rows: 3,
          }}
        >
          {exams.map((item, index) => (
            <SwiperSlide
              className={`exam-swiper-slide  rounded-lg ${
                item.isFree && "shadow-base"
              }`}
              key={index.toString()}
            >
              <ExamCard
              exam={item}
                isFree={item.isFree}
                testResult={item?.testResult}
                locked={!item.isFree}
                onClick={handleSetExam}
              />
            </SwiperSlide>
          ))}
        </Swiper>
      </div>
      <div className="w-full flex items-center justify-between">
        <IconButton disabled={isBeginning} onClick={handlePrev}>
          <ChevronRight />
        </IconButton>

        <IconButton onClick={handleNext} disabled={isEnd}>
          <ChevronLeft />
        </IconButton>
      </div>
    </div>
  );
};

export default ExamsListSwiperDemo;
